@@ -618,15 +618,6 @@ effect:
         self.ImgRec()
 
     def ImgRec(self ):
-        # Re init GAN
-        self.gan = self.create_gan(reinit = True)
-        self.gan.get_layer(index=1).set_weights(self.gen.get_weights())
-        if self.resetOpt == True:
-            opt = 'optimizers.'+self.opt._name
-            opt = eval(opt)
-            opt = opt.from_config(self.opt.get_config())
-            self.gan.compile(loss=[CrossEntropy, data_loss], optimizer= opt,loss_weights=[mu,1])
-
         # get parameters
         params = self.params
         mu = params['mu']
@@ -634,6 +625,7 @@ effect:
         data_loss = self.set_dataloss()
 
 
+
         outdir = os.path.join(os.getcwd(),self.dir)
 
         Chi2s, DisLoss = [], []
@@ -643,7 +635,14 @@ effect:
         if self.diagnostics:
             print('#restart\tftot\tfdata\tfdiscriminator')
         for r in iteration:
-
+            # Re init GAN
+            self.gan = self.create_gan(reinit = True)
+            #self.gan.get_layer(index=1).set_weights(self.gen.get_weights())
+            if self.resetOpt == True:
+                opt = 'optimizers.'+self.opt._name
+                opt = eval(opt)
+                opt = opt.from_config(self.opt.get_config())
+                self.gan.compile(loss=[CrossEntropy, data_loss], optimizer=opt, loss_weights=[mu,1])
 
             # generating the noise vector for this restart
             noisevector = np.array([np.random.normal(0, 1, 100)])
